.. include:: /_includes/wip_prolog.rst

:mod:`stix.extensions.malware.maec_4_1_malware` Module
======================================================

.. module:: stix.extensions.malware.maec_4_1_malware

Classes
-------

.. autoclass:: MAECInstance
	:show-inheritance:
	:members:
